@@ -1,4 +1,4 @@
-# $Id: Config.pm 8286 2013-09-12 08:26:11Z hurko $
+# $Id: Config.pm 8490 2013-11-07 10:09:29Z hurko $
 # $URL: https://pong.uvt.nl/its-nettel/Netwerken/Procedures/libuvt-noc-perl/lib/UvT/NOC/Config.pm $
 
 use utf8;
@@ -11,6 +11,8 @@ use Clarity -base;
 
 use XML::LibXML;
 
+use UvT::NOC::Config::SettingList;
+use UvT::NOC::Config::Setting;
 use UvT::NOC::Config::ResourceList;
 use UvT::NOC::Config::Resource;
 use UvT::NOC::Config::ResourceFileList;
@@ -30,6 +32,31 @@ sub new
 	);
 }
 
+sub getSetting
+{
+	my($self, $name) = @_;
+	my $doc = $self->doc;
+
+	my $setting = undef;
+
+	die "Cannot find node 'settings'\n"
+		unless $doc->exists('/config/settings');
+
+	foreach my $settingNode ($doc->findnodes('/config/settings/setting'))
+	{
+		if ($settingNode->getAttribute('name') eq $name)
+		{
+			# print "Found node with name : " . $settingNode->getAttribute('name') . "\n";
+			$setting = $settingNode->textContent;
+		}
+	}
+
+	die "Cannot find setting with name $name\n"
+		unless defined $setting;
+
+	return $setting;
+}
+
 sub getFile
 {
 	my($self, $name) = @_;
@@ -80,6 +107,38 @@ sub getDirectory
 	return $directory;
 }
 
+sub getSettings
+{
+	my ($self) = @_;
+	my $doc = $self->doc;
+
+	my $settings = new UvT::NOC::Config::SettingList();
+
+	die "Cannot find node 'settings'\n"
+		unless $doc->exists('/config/settings');
+
+	foreach my $settingNode ($doc->findnodes('/config/settings/setting'))
+	{
+		my $settingName = $settingNode->getAttribute('name');
+		# print "-- > $settingName\n";
+		my $setting = new UvT::NOC::Config::Setting($settingName);
+
+		foreach my $propertyNode ($settingNode->findnodes('property'))
+		{
+			#print Dumper($settingNode->toString(1));
+			my $propertyName = $propertyNode->getAttribute('name');
+			my $propertyValue = $propertyNode->textContent;
+			#print "\t$propertyName\t\t$propertyValue\n";
+
+			my $property = new UvT::NOC::Config::Property($propertyName, $propertyValue);
+			$setting->addProperty($property);
+		}
+		$settings->addSetting($setting);
+	}
+
+	return $settings; 
+}
+
 sub getResources
 {
 	my ($self) = @_;
@@ -120,7 +179,7 @@ sub getResourceFiles
     my $resourceFiles = new UvT::NOC::Config::ResourceFileList();
 
     die "Cannot find node 'resourceFiles'\n"
-            unless $doc->exists('/config/resourceFiles');
+		unless $doc->exists('/config/resourceFiles');
 
     foreach my $resourceFileNode ($doc->findnodes('/config/resourceFiles/resourceFile'))
     {
